==> git-3.9.1-sources.jar: jenkins/plugins/git/traits/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.plugins.git.traits;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code TagDiscoveryTrait.authorityDisplayName}: {@code Trust
     * tags}.
     * 
     * @return
     *     {@code Trust tags}
     */
    public static String TagDiscoveryTrait_authorityDisplayName() {
        return holder.format("TagDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.authorityDisplayName}: {@code Trust
     * tags}.
     * 
     * @return
     *     {@code Trust tags}
     */
    public static Localizable _TagDiscoveryTrait_authorityDisplayName() {
        return new Localizable(holder, "TagDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.displayName}: {@code Discover
     * branches}.
     * 
     * @return
     *     {@code Discover branches}
     */
    public static String BranchDiscoveryTrait_displayName() {
        return holder.format("BranchDiscoveryTrait.displayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.displayName}: {@code Discover
     * branches}.
     * 
     * @return
     *     {@code Discover branches}
     */
    public static Localizable _BranchDiscoveryTrait_displayName() {
        return new Localizable(holder, "BranchDiscoveryTrait.displayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.authorityDisplayName}: {@code Trust
     * branches}.
     * 
     * @return
     *     {@code Trust branches}
     */
    public static String BranchDiscoveryTrait_authorityDisplayName() {
        return holder.format("BranchDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.authorityDisplayName}: {@code Trust
     * branches}.
     * 
     * @return
     *     {@code Trust branches}
     */
    public static Localizable _BranchDiscoveryTrait_authorityDisplayName() {
        return new Localizable(holder, "BranchDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code DiscoverOtherRefsTrait.displayName}: {@code Discover other
     * refs}.
     * 
     * @return
     *     {@code Discover other refs}
     */
    public static String DiscoverOtherRefsTrait_displayName() {
        return holder.format("DiscoverOtherRefsTrait.displayName");
    }

    /**
     * Key {@code DiscoverOtherRefsTrait.displayName}: {@code Discover other
     * refs}.
     * 
     * @return
     *     {@code Discover other refs}
     */
    public static Localizable _DiscoverOtherRefsTrait_displayName() {
        return new Localizable(holder, "DiscoverOtherRefsTrait.displayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.displayName}: {@code Discover tags}.
     * 
     * @return
     *     {@code Discover tags}
     */
    public static String TagDiscoveryTrait_displayName() {
        return holder.format("TagDiscoveryTrait.displayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.displayName}: {@code Discover tags}.
     * 
     * @return
     *     {@code Discover tags}
     */
    public static Localizable _TagDiscoveryTrait_displayName() {
        return new Localizable(holder, "TagDiscoveryTrait.displayName");
    }

}

==> git-4.4.5-sources.jar: jenkins/plugins/git/traits/Messages.java <==
// CHECKSTYLE:OFF

package jenkins.plugins.git.traits;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;
import org.kohsuke.accmod.Restricted;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
@Restricted(org.kohsuke.accmod.restrictions.NoExternalUse.class)
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code Advanced.clone.behaviours}: {@code Advanced clone
     * behaviours}.
     * 
     * @return
     *     {@code Advanced clone behaviours}
     */
    public static String Advanced_clone_behaviours() {
        return holder.format("Advanced.clone.behaviours");
    }

    /**
     * Key {@code Advanced.clone.behaviours}: {@code Advanced clone
     * behaviours}.
     * 
     * @return
     *     {@code Advanced clone behaviours}
     */
    public static Localizable _Advanced_clone_behaviours() {
        return new Localizable(holder, "Advanced.clone.behaviours");
    }

    /**
     * Key {@code TagDiscoveryTrait.authorityDisplayName}: {@code Trust
     * tags}.
     * 
     * @return
     *     {@code Trust tags}
     */
    public static String TagDiscoveryTrait_authorityDisplayName() {
        return holder.format("TagDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.authorityDisplayName}: {@code Trust
     * tags}.
     * 
     * @return
     *     {@code Trust tags}
     */
    public static Localizable _TagDiscoveryTrait_authorityDisplayName() {
        return new Localizable(holder, "TagDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.displayName}: {@code Discover
     * branches}.
     * 
     * @return
     *     {@code Discover branches}
     */
    public static String BranchDiscoveryTrait_displayName() {
        return holder.format("BranchDiscoveryTrait.displayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.displayName}: {@code Discover
     * branches}.
     * 
     * @return
     *     {@code Discover branches}
     */
    public static Localizable _BranchDiscoveryTrait_displayName() {
        return new Localizable(holder, "BranchDiscoveryTrait.displayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.authorityDisplayName}: {@code Trust
     * branches}.
     * 
     * @return
     *     {@code Trust branches}
     */
    public static String BranchDiscoveryTrait_authorityDisplayName() {
        return holder.format("BranchDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code BranchDiscoveryTrait.authorityDisplayName}: {@code Trust
     * branches}.
     * 
     * @return
     *     {@code Trust branches}
     */
    public static Localizable _BranchDiscoveryTrait_authorityDisplayName() {
        return new Localizable(holder, "BranchDiscoveryTrait.authorityDisplayName");
    }

    /**
     * Key {@code DiscoverOtherRefsTrait.displayName}: {@code Discover other
     * refs}.
     * 
     * @return
     *     {@code Discover other refs}
     */
    public static String DiscoverOtherRefsTrait_displayName() {
        return holder.format("DiscoverOtherRefsTrait.displayName");
    }

    /**
     * Key {@code DiscoverOtherRefsTrait.displayName}: {@code Discover other
     * refs}.
     * 
     * @return
     *     {@code Discover other refs}
     */
    public static Localizable _DiscoverOtherRefsTrait_displayName() {
        return new Localizable(holder, "DiscoverOtherRefsTrait.displayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.displayName}: {@code Discover tags}.
     * 
     * @return
     *     {@code Discover tags}
     */
    public static String TagDiscoveryTrait_displayName() {
        return holder.format("TagDiscoveryTrait.displayName");
    }

    /**
     * Key {@code TagDiscoveryTrait.displayName}: {@code Discover tags}.
     * 
     * @return
     *     {@code Discover tags}
     */
    public static Localizable _TagDiscoveryTrait_displayName() {
        return new Localizable(holder, "TagDiscoveryTrait.displayName");
    }

}
